@@ -1,18 +1,11 @@
 /*
- * "$Id: adminutil.h 7026 2007-10-19 00:57:45Z mike $"
+ * Administration utility API definitions for CUPS.
  *
- *   Administration utility API definitions for CUPS.
+ * Copyright 2020-2024 by OpenPrinting.
+ * Copyright 2007-2016 by Apple Inc.
+ * Copyright 2001-2007 by Easy Software Products.
  *
- *   Copyright 2007-2012 by Apple Inc.
- *   Copyright 2001-2007 by Easy Software Products.
- *
- *   These coded instructions, statements, and computer programs are the
- *   property of Apple Inc. and are protected by Federal copyright
- *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- *   which should have been included with this file.  If this file is
- *   file is missing or damaged, see the license at "http://www.cups.org/".
- *
- *   This file is subject to the Apple OS-Developed Software exception.
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
  */
 
 #ifndef _CUPS_ADMINUTIL_H_
@@ -42,11 +35,23 @@ extern "C" {
 #  define CUPS_SERVER_DEBUG_LOGGING	"_debug_logging"
 #  define CUPS_SERVER_REMOTE_ADMIN	"_remote_admin"
 #  define CUPS_SERVER_REMOTE_ANY	"_remote_any"
-/*#  define CUPS_SERVER_REMOTE_PRINTERS	"_remote_printers"*/
 #  define CUPS_SERVER_SHARE_PRINTERS	"_share_printers"
 #  define CUPS_SERVER_USER_CANCEL_ANY	"_user_cancel_any"
 
 
+/*
+ * Types and structures...
+ */
+
+typedef void (*cups_device_cb_t)(const char *device_class,
+                                 const char *device_id, const char *device_info,
+                                 const char *device_make_and_model,
+                                 const char *device_uri,
+				 const char *device_location, void *user_data);
+					/* Device callback
+					 * @since CUPS 1.4/macOS 10.6@ */
+
+
 /*
  * Functions...
  */
@@ -69,13 +74,15 @@ extern int	cupsAdminSetServerSettings(http_t *http,
 		                           cups_option_t *settings)
 		                           _CUPS_API_1_3;
 
+extern ipp_status_t	cupsGetDevices(http_t *http, int timeout,
+			               const char *include_schemes,
+			               const char *exclude_schemes,
+				       cups_device_cb_t callback,
+				       void *user_data) _CUPS_DEPRECATED;
+
 
 #  ifdef __cplusplus
 }
 #  endif /* __cplusplus */
 
 #endif /* !_CUPS_ADMINUTIL_H_ */
-
-/*
- * End of "$Id: adminutil.h 7026 2007-10-19 00:57:45Z mike $".
- */
